@@ -82,8 +82,8 @@ class Rethink_DBS(GeneralData):
 
     async def close(self):
         if self.session:
-            await self.session.close(noreply_wait=True)
-        super().close()
+            await self.session.close(noreply_wait=False)
+        await super().close()
 
     async def reconnect(self, wait=False):
         await self.session.reconnect(noreply_wait=wait)
